@@ -1,6 +1,6 @@
 pub use defer::defer;
 pub use error::{Ignore, SafeUnwrap};
-pub use input::{input, input_string, Prompt};
+pub use input::{input, input_string, prompt, Prompt};
 
 mod defer;
 mod error;
